pyxmpp.jabber.vcard.VCardXString

Package pyxmpp :: Package jabber :: Module vcard :: Class VCardXString |
[hide private]

# Class VCardXString

source code

    VCardField --+
                 |
       VCardString --+
                     |
                    VCardXString

Generic class for all text vCard fields not defined in RFC 2426.

In the RFC 2425 representation field name will be prefixed with 'x-'.

Instance Methods | [hide private]
`str` |
rfc2426(self) RFC2426-encode the field content. | source code
Inherited from `VCardString`: `__init__`, `__str__`, `__unicode__`, `as_xml` Inherited from `VCardField`: `__repr__`

Instance Variables | [hide private]
`unicode` | value field value.
Inherited from `VCardField`: `name`

Method Details | [hide private]

### rfc2426(self) | source code
RFC2426-encode the field content. Returns: `str` the field in the RFC 2426 format. Overrides: VCardField.rfc2426